# nodejs10-oracledb.spec
#
# Builds the node-oracledb driver for Node.js 10
#
# A zip file downloaded from the node-oracledb github tag should be in
# SOURCES/node-oracledb-x.y.z.zip

# The version of node-oracledb extension being installed
%define nodeoracledbver 4.2.0

# The Node.js version
%define nodejsmainver 10
%define nextnodejsver 11
%define nodejspatchver 4.1
%define nodejsver %{nodejsmainver}.%{nodejspatchver}

# Instant Client version
%define ocimainver 19.5
%define ocipatchver 0.0.0
%define ociver %{ocimainver}.%{ocipatchver}

# odpi as a seperate package
%define odpiver 3.3.0
# Can't use %{_libdir} since it is /usr/lib64
%define mylibdir /usr/lib

# Test DB connection string and SYSTEM password
%define connectstring  localhost/orcl
%define systempw oracle

Summary: The node-oracledb add-on allows Node.js applications to connect to Oracle Database
Name: node-oracledb-node%{nodejsmainver}
Group: Development/Languages
Version: %{nodeoracledbver}
Release: 1.0.1%{?dist}
License: Apache 2.0
URL: https://github.com/oracle/node-oracledb/

# This is the GitHub URL to pull from:
#   https://github.com/oracle/node-oracledb/archive/v%{nodeoracledbver}.zip
# The file name that is downloaded from that GitHub URL needs to be used:
Source0: node-oracledb-%{nodeoracledbver}.zip
Source1: createtestuser.sql
Source2: droptestuser.sql
Source3: odpi-%{odpiver}.zip


BuildRequires: nodejs >= %{nodejsmainver}, nodejs < %{nextnodejsver}
BuildRequires: oracle-instantclient%{ocimainver}-basic >= %{ociver}
BuildRequires: oracle-instantclient%{ocimainver}-devel >= %{ociver}
BuildRequires: oracle-instantclient%{ocimainver}-sqlplus >= %{ociver}
BuildRequires: devtoolset-4-gcc-c++

Requires: nodejs >= %{nodejsmainver}, nodejs < %{nextnodejsver}
Requires: oracle-instantclient19.5-basic >= %{ociver}

# Stop install of the generated RPM failing with the error: "Requires: libclntsh.so.12.1()(64bit)"
AutoReqProv: no

Provides: nodejs-oracledb = %{version}-%{release}

Obsoletes: node-oracledb-12c-node%{nodejsmainver}

%description
The node-oracledb add-on for Node.js powers high performance Oracle Database applications.

%prep
%setup -q -c -n node-oracledb-%{version}
rm -rf %{_builddir}/odpi-%{odpiver}
%setup -T -D -a 3 -q -c -n odpi-%{odpiver}
mv -f %{_builddir}/odpi-%{odpiver}/odpi*/*  %{_builddir}/node-oracledb-%{version}/node-oracledb-%{version}/odpi
rm -rf %{_builddir}/node_modules
mkdir %{_builddir}/node_modules
npm cache verify

%build
cd %{_builddir}

npm config set registry https://artifacthub-tip.oraclecorp.com/api/npm/npmjs-remote/

# Workaround PATH getting reset by npm
export CXX=/opt/rh/devtoolset-4/root/usr/bin/g++

npm install nan
cd node-oracledb-%{nodeoracledbver}/node-oracledb-%{nodeoracledbver}
scl enable devtoolset-4 -- npm install
cd ../..
mv node-oracledb-%{nodeoracledbver}/node-oracledb-%{nodeoracledbver} node_modules/oracledb
unset CXX

%check

# Note this tests the install in the build dir, not the buildroot. The latter is packaged up.
runtests() {

    cd %{_builddir}/node-oracledb-%{nodeoracledbver}

    export PATH=/usr/lib/oracle/%{ocimainver}/client64/bin:$PATH
    export LD_LIBRARY_PATH=/usr/lib/oracle/%{ocimainver}/client64/lib:$LD_LIBRARY_PATH

    npm install mocha should async

    # Create a temporary DB user and run the tests
    export NODE_ORACLEDB_USER='nodetest'$$
    export NODE_ORACLEDB_PASSWORD=$NODE_ORACLEDB_USER
    export NODE_ORACLEDB_CONNECTIONSTRING=%{connectstring}
    sqlplus  -l system/%{systempw}@$NODE_ORACLEDB_CONNECTIONSTRING @%{_sourcedir}/createtestuser.sql $NODE_ORACLEDB_USER $NODE_ORACLEDB_PASSWORD
    cd %{_builddir}/node_modules/oracledb
    npm test
    sqlplus -l system/%{systempw}@$NODE_ORACLEDB_CONNECTIONSTRING @%{_sourcedir}/droptestuser.sql $NODE_ORACLEDB_USER

}

# Comment out the following 'runtests' line to skip testing
#runtests

%install
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

mkdir -p $RPM_BUILD_ROOT

install -m 755 -d $RPM_BUILD_ROOT%{mylibdir}/node_modules/oracledb/build/Release
install -m 755 %{_builddir}/node_modules/oracledb/build/Release/oracledb.node $RPM_BUILD_ROOT%{mylibdir}/node_modules/oracledb/build/Release
install -m 755 -d $RPM_BUILD_ROOT%{mylibdir}/node_modules/oracledb/lib
install -m 644 %{_builddir}/node_modules/oracledb/lib/*.js $RPM_BUILD_ROOT%{mylibdir}/node_modules/oracledb/lib/
install -m 644 %{_builddir}/node_modules/oracledb/index.js $RPM_BUILD_ROOT%{mylibdir}/node_modules/oracledb
install -m 644 %{_builddir}/node_modules/oracledb/LICENSE.md $RPM_BUILD_ROOT%{mylibdir}/node_modules/oracledb
install -m 644 %{_builddir}/node_modules/oracledb/README.md $RPM_BUILD_ROOT%{mylibdir}/node_modules/oracledb
install -m 644 %{_builddir}/node_modules/oracledb/package.json $RPM_BUILD_ROOT%{mylibdir}/node_modules/oracledb

%clean
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%{mylibdir}/node_modules/oracledb/*

%changelog
* Tue Jan 21 2020 EL Errata <el-errata_ww@oracle.com> 4.2.0-1
- Update to version 4.2.0

* Wed Dec 18 2019 Qing Lin <qing.lin@oracle.com> 4.1.0-1.0.1
- update odpi to 3.3.0

* Mon Nov 25 2019 EL Errata <el-errata_ww@oracle.com> 4.1.0-1
- Update node-oracledb to 4.1.0 and odpi to 3.2.2

* Sun Aug 18 2019 EL Errata <el-errata_ww@oracle.com> 4.0.1-1
- Update node-oracledb to 4.0.1 and odpi to 3.2.1

* Wed Jul 24 2019 EL Errata <el-errata_ww@oracle.com> 4.0.0-1
- Update node-oracledb to 4.0.0 and odpi to 3.2.0

* Thu Feb 21 2019 EL Errata <el-errata_ww@oracle.com> 3.1.2-1
- Update node-oracledb to 3.1.2 and odpi to 3.1.2

* Thu Jan 24 2019 EL Errata <el-errata_ww@oracle.com> 3.1.1-1
- Update to version 3.1.1

* Tue Jan 22 2019 EL Errata <el-errata_ww@oracle.com> 3.1.0-1
- Update node-oracledb to 3.1.0 and odpi to 3.1.0

* Wed Dec 05 2018 EL Errata <el-errata_ww@oracle.com> 3.0.1-1
- Update to version 3.0.1

* Tue Oct 02 2018 John Mcwalters <john.mcwalters@oracle.com> 3.0.0-1
- Update node-oracledb to 3.0.0 and odpi to 3.0.0
- Use instantclient version 18.3

* Fri Jun 08 2018 Srinivas Maturi <sriniva.maturi@oracle.com> - 2.3.0
-- upgrade to version 2.3.0, odpi to 2.4.0

* Tue Apr 3 2018 Qing Lin          <qing.lin@oracle.com>          - 2.2.0
  -- upgrade to version 2.2.0, odpi to 2.3.0

* Wed Mar 07 2018 Qing Lin          <qing.lin@oracle.com>          - 2.1.2
  -- upgrade to version 2.1.2

* Tue Feb 20 2018 Qing Lin          <qing.lin@oracle.com>          - 2.1.1
  -- upgrade to version 2.1.1.

* Thu Dec 21 2017 Qing Lin          <qing.lin@oracle.com>     	   - 2.0.15 
  -- setup auto-build 
  -- add package odpi as a source file.

* Thu Jun  8 2017 Qing Lin          <qing.lin@oracle.com>     	   - 1.13.1 setup auto-build
* Mon Jan 30 2017 P. Venkatraman    <p.venkatraman@oracle.com>     - 1.12.2
* Mon Jan 30 2017 P. Venkatraman    <p.venkatraman@oracle.com>     - 1.12.2
* Fri Nov  4 2016 Christopher Jones <christopher.jones@oracle.com> - Created
